package com.hh.hhomc.deviceui;

import android.app.Activity;
import android.content.Intent;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;

import com.hh.hhomc.MyApplication;
import com.innohi.YNHAPI;
import com.roco.api.weigenRelay.weigenRelay;

/**
 * 紫鹏
 */
public class ZpA50DeviceUI implements IDeviceUI{


    //用volatile关键字确保 instance 在多线程下的可见性
    private static volatile ZpA50DeviceUI instance = null;

    //将构造方法私有化，禁止外部通过构造方法创建实例
    private ZpA50DeviceUI() {}

    //提供一个公共的访问方法，用于获取该类的唯一实例
    public static ZpA50DeviceUI getInstance() {
        //如果instance为空，就进行实例化
        if (instance == null) {
            //保证多线程下只有一个线程进行实例化
            synchronized (ZpA50DeviceUI.class) {
                //第二次判断，避免多线程下创建多个实例
                if (instance == null) {
                    instance = new ZpA50DeviceUI();
                }
            }
        }
        return instance;
    }


    @Override
    public void showNotification() {
        Intent intent = new Intent();
        intent.setAction("com.custom.open.statubar");
        intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
        MyApplication.getContext().sendBroadcast(intent);
    }

    @Override
    public void hideNotification() {
        Intent intent = new Intent();
        intent.setAction("com.custom.close.statubar");
        intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
        MyApplication.getContext().sendBroadcast(intent);
    }

    @Override
    public void showNavigationBar() {
        Intent intent = new Intent();
        intent.setAction("com.custom.show_navigationbar");
        intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
        MyApplication.getContext().sendBroadcast(intent);
    }

    @Override
    public void hideNavigationBar() {
        Intent intent = new Intent();
        intent.setAction("com.custom.hide_navigationbar");
        intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
        MyApplication.getContext().sendBroadcast(intent);
    }

    @Override
    public void showFillLight() {

    }

    @Override
    public void hideFillLight() {

    }



    @Override
    public void reboot() {

        try {
            YNHAPI mAPI = YNHAPI.getInstance();
            mAPI.reboot();
        }catch (Exception e){

        }
    }

    @Override
    public void silenceInstall(String path,SilenceInstallSuccessListener listener) {
        if(TextUtils.isEmpty(path)){
            return ;
        }
        try {
            YNHAPI mAPI = YNHAPI.getInstance();
            mAPI.installApkSilently(path,null,null);
            if(listener!=null){
                listener.success(true);
            }
        }catch (Exception e){
            if(listener!=null){
                listener.success(false);
            }
        }

    }


    //Todo 目前还无法使用
    @Override
    public void silenceUnInstall(String packageName) {

    }

    @Override
    public void startAPP(String packageName) {
        if(TextUtils.isEmpty(packageName)){
            return;
        }
        Intent intent = MyApplication.getContext().getPackageManager().getLaunchIntentForPackage(packageName);
        try {
            if (intent != null) {
                MyApplication.getContext().startActivity(intent);
            } else {
                // 应用无法启动
            }
        }catch (Exception e){

        }
    }


}
